import React, { useState } from "react";
import {
    ButtonCollapse,
    ButtonVolume,
    Audio,
    Duration,
    Footer,
    Header,
    MainButtons,
    Info,
    PlaylistName,
    TrackName,
    Volume,
    VolumeSettings,
    Wrapper,
    StatusButton,
    NextButton,
    RepeatButton,
    PreviousButton,
    ShuffleButton,
} from "./style";

import CollapseIcon from "../../assets/collapse_icon.svg";
import ShuffleIcon from "../../assets/shuffle_icon.svg";
import PreviousIcon from "../../assets/previous_icon.svg";
import NextIcon from "../../assets/next_icon.svg";
import PlayIcon from "../../assets/play_icon.svg";
import StopIcon from "../../assets/stop_icon.svg";
import RepeatIcon from "../../assets/repeat_icon.svg";
import VolumeUpIcon from "../../assets/volume_up_icon.svg";
import VolumeStopIcon from "../../assets/volume_stop_icon.svg";

const Player = () => {
    const [isPlaying, setIsPlaying] = useState(false);
    const [duration, setDuration] = useState(0);
    const [currentTime, setCurrentTime] = useState(0);
    const [track, setTrack] = useState({}); // props track
    const [playlist, setPlaylist] = useState([]); // arr with tracks and their props
    const [playlistIndex, setPlaylistIndex] = useState([]);
    const [volume, setVolume] = useState(50);

    const [isCollapsed, setIsCollapsed] = useState(false);
    const [isRepeated, setIsRepeated] = useState(false);

    return (
        <Wrapper isCollapsed={isCollapsed}>
            <Header>
                <Duration>0:00:00</Duration>
                <Audio
                    type={"range"}
                    min={0}
                    max={100}
                    value={currentTime}
                    onChange={(e) => {
                        setCurrentTime(e.target.value);
                    }}
                />
                <ButtonCollapse
                    src={CollapseIcon}
                    isCollapsed={isCollapsed}
                    onClick={() => setIsCollapsed(!isCollapsed)} // change to redux
                />
            </Header>
            {!isCollapsed ? (
                <Footer>
                    <Info>
                        <PlaylistName>Here is playlist</PlaylistName>
                        <TrackName>Here is track</TrackName>
                    </Info>
                    <MainButtons>
                        <ShuffleButton src={ShuffleIcon} />
                        <PreviousButton src={PreviousIcon} />
                        <StatusButton
                            src={isPlaying ? StopIcon : PlayIcon}
                            isPlaying={isPlaying}
                            onClick={() => setIsPlaying(!isPlaying)} // redux
                        />
                        <NextButton src={NextIcon} />
                        <RepeatButton
                            src={RepeatIcon}
                            isRepeated={isRepeated}
                            onClick={() => setIsRepeated(!isRepeated)} // change to redux
                        />
                    </MainButtons>
                    <VolumeSettings>
                        <ButtonVolume
                            src={volume ? VolumeUpIcon : VolumeStopIcon}
                            onClick={() =>
                                volume ? setVolume(0) : setVolume(100) // redux
                            }
                        />
                        <Volume
                            type={"range"}
                            min={0}
                            max={100}
                            value={volume}
                            onChange={(e) => {
                                setVolume(e.target.value);
                            }}
                        ></Volume>
                    </VolumeSettings>
                </Footer>
            ) : null}
        </Wrapper>
    );
};

export default Player;
